ryvencore.logging.Logger module - ryvencore v0.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Toggle table of contents sidebar

# ryvencore.logging.Logger module

class Logger

  Bases: `ryvencore.Base.Base`, `logging.Logger`

  A small wrapper template for the python loggers to add functionality on node events. Reimplemented as wrapper by the frontend with according implementations of the below methods.

  sig_enabled = <ryvencore.Base.Event object>
  sig_disabled = <ryvencore.Base.Event object>
  enable()
  disable()